--[[
	Copyright (C) Udorn (Blackhand)
--]]

local viewType = "AchievementHeader"
local version = 1
local YakaGui = LibStub("YakaGui", true)
local info = YakaGui:GetViewInfo(viewType) 
if (info and info.version >= version) then 
	return 
end

qmstr = qmstr or {}
qmstr.AchievementHeader = {}
qmstr.AchievementHeader.prototype = {}
qmstr.AchievementHeader.metatable = {__index = qmstr.AchievementHeader.prototype}
setmetatable(qmstr.AchievementHeader.prototype, {__index = yaka.Container.prototype})

qmstr.AchievementHeader.info = {viewType = viewType, version = version}
qmstr.AchievementHeader.GetViewInfo = function()
	return qmstr.AchievementHeader.info
end

local ICON_SIZE = 16

local log = vendor.Debug:new("AchievementHeader")

local function _Init(self, cfgIn)
	self:InitCfg(cfgIn)
	self.profile = qmstr.QuestMaster.db.profile
		
	local cfg = self.cfg
	
	cfg.collapseable = cfgIn.collapseable
	self.order = 1
	
	cfg.layout = {
		layoutType = "LinearLayout",
		vertical = false
	}
	
	self.collapse = YakaGui:CreateView({
		viewType = "ToggleIcon",
		order = 1,
		width = ICON_SIZE,
		height = ICON_SIZE,
   		checkedNormalTexture = {
			file = "Interface\\Addons\\QuestMaster\\resources\\Button-Plus-Up",
			texCoords = BUTTON_TEX_COORDS
		},
		checkedPushedTexture = {
			file = "Interface\\Addons\\QuestMaster\\resources\\Button-Plus-Down",
			texCoords = BUTTON_TEX_COORDS
		},
		uncheckedNormalTexture = {
			file = "Interface\\Addons\\QuestMaster\\resources\\Button-Minus-Up",
			texCoords = BUTTON_TEX_COORDS
		},
		uncheckedPushedTexture = {
			file = "Interface\\Addons\\QuestMaster\\resources\\Button-Minus-Down",
			texCoords = BUTTON_TEX_COORDS
		},
		highlightTexture = {
			file = "Interface\\Addons\\QuestMaster\\resources\\Button-Highlight",
			alphaMode = "ADD"
		},
		setValue = function(info) info.arg.profile.achievementCollapsed = info.value; qmstr.QuestMaster:UpdateWindow() end,
		getValue = function(info) return info.arg.profile.achievementCollapsed end,
		arg = self
	})

	self.title = YakaGui:CreateView({
		viewType = "Text",
		order = 2,
		height = 12,
		width = "fill",
		font = "QuestMasterNormal",
	})

	self:InitFrame(nil)
	
	self:SetCollapseable(self.cfg.collapseable)
end

--[[ 
	Creates a new instance.
--]]
function qmstr.AchievementHeader:new(cfgIn, parent)
	local instance = setmetatable({}, self.metatable)
	_Init(instance, cfgIn, parent)
	return instance
end

function qmstr.AchievementHeader.prototype:SetCollapseable(collapseable)

	self.title:SetText(YakaGui:GetFontColorCode(unpack(self.profile.headerColor))..ACHIEVEMENTS..FONT_COLOR_CODE_CLOSE)
		
	self:RemoveChildViews()
	
	self.cfg.collapsed = collapsed
	self.cfg.collapseable = collapseable
	if (collapseable) then
		log:Debug("set checked [%s]", self.profile.achievementCollapsed)
		self.collapse:SetChecked(self.profile.achievementCollapsed)
   		self:AddChildView(self.collapse)
   	end
	self:AddChildView(self.title)
end

-- register view

YakaGui:RegisterViewType(qmstr.AchievementHeader)